==> spotbugs-maven-plugin-3.1.3.1-sources.jar: org/codehaus/mojo/spotbugs/XDocsReporter.java <==
package org.codehaus.mojo.spotbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class XDocsReporter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public XDocsReporter
(java.util.ResourceBundle bundle, org.apache.maven.plugin.logging.Log log, java.lang.String threshold, java.lang.String effort, java.lang.String outputEncoding) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.lang.String getNOLINE_KEY() { return (java.lang.String)null;}
public  java.util.ResourceBundle getBundle() { return (java.util.ResourceBundle)null;}
public  void setBundle(java.util.ResourceBundle value) { }
public  org.apache.maven.plugin.logging.Log getLog() { return (org.apache.maven.plugin.logging.Log)null;}
public  void setLog(org.apache.maven.plugin.logging.Log value) { }
public  java.lang.String getThreshold() { return (java.lang.String)null;}
public  void setThreshold(java.lang.String value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.io.Writer getOutputWriter() { return (java.io.Writer)null;}
public  void setOutputWriter(java.io.Writer value) { }
public  groovy.util.slurpersupport.GPathResult getSpotbugsResults() { return (groovy.util.slurpersupport.GPathResult)null;}
public  void setSpotbugsResults(groovy.util.slurpersupport.GPathResult value) { }
public  java.util.List getBugClasses() { return (java.util.List)null;}
public  void setBugClasses(java.util.List value) { }
public  java.util.List getCompileSourceRoots() { return (java.util.List)null;}
public  void setCompileSourceRoots(java.util.List value) { }
public  java.util.List getTestSourceRoots() { return (java.util.List)null;}
public  void setTestSourceRoots(java.util.List value) { }
public  java.lang.String getOutputEncoding() { return (java.lang.String)null;}
public  void setOutputEncoding(java.lang.String value) { }
protected  java.lang.String evaluateThresholdParameter(java.lang.String thresholdValue) { return (java.lang.String)null;}
protected  java.lang.String getSpotBugsVersion() { return (java.lang.String)null;}
public  void generateReport() { }
}

==> spotbugs-maven-plugin-4.5.3.0-sources.jar: org/codehaus/mojo/spotbugs/XDocsReporter.java <==
package org.codehaus.mojo.spotbugs;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;

public class XDocsReporter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public XDocsReporter
(java.util.ResourceBundle bundle, org.apache.maven.plugin.logging.Log log, java.lang.String threshold, java.lang.String effort, java.lang.String outputEncoding) {}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.lang.String getNOLINE_KEY() { return (java.lang.String)null;}
public  java.util.ResourceBundle getBundle() { return (java.util.ResourceBundle)null;}
public  void setBundle(java.util.ResourceBundle value) { }
public  org.apache.maven.plugin.logging.Log getLog() { return (org.apache.maven.plugin.logging.Log)null;}
public  void setLog(org.apache.maven.plugin.logging.Log value) { }
public  java.lang.String getThreshold() { return (java.lang.String)null;}
public  void setThreshold(java.lang.String value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.io.Writer getOutputWriter() { return (java.io.Writer)null;}
public  void setOutputWriter(java.io.Writer value) { }
public  groovy.xml.slurpersupport.GPathResult getSpotbugsResults() { return (groovy.xml.slurpersupport.GPathResult)null;}
public  void setSpotbugsResults(groovy.xml.slurpersupport.GPathResult value) { }
public  java.util.List getBugClasses() { return (java.util.List)null;}
public  void setBugClasses(java.util.List value) { }
public  java.util.List getCompileSourceRoots() { return (java.util.List)null;}
public  void setCompileSourceRoots(java.util.List value) { }
public  java.util.List getTestSourceRoots() { return (java.util.List)null;}
public  void setTestSourceRoots(java.util.List value) { }
public  java.lang.String getOutputEncoding() { return (java.lang.String)null;}
public  void setOutputEncoding(java.lang.String value) { }
protected  java.lang.String evaluateThresholdParameter(java.lang.String thresholdValue) { return (java.lang.String)null;}
protected  java.lang.String getSpotBugsVersion() { return (java.lang.String)null;}
public  void generateReport() { }
}
